@@ -13,7 +13,8 @@ class FocalLoss(nn.Module):
 
     def forward(self, x, target):
         p_t = torch.where(target == 1, x, 1-x)
-        fl = - self.alpha * (1 - p_t) ** self.gamma * torch.log(p_t)
+        a_t = torch.where(target == 1, self.alpha, 1 - self.alpha)
+        fl = - a_t * (1 - p_t) ** self.gamma * torch.log(p_t)
         return self._reduce(fl)
 
     def _reduce(self, x):
